## ----components, echo=FALSE, eval=TRUE, fig.cap='(ref:components)', fig.align="center", out.width = '50%'----
knitr::include_graphics("Figures/Part2/fishPCA.png")


## ---- echo = TRUE, eval = TRUE, results='show'-------
library(mixOmics)
data("linnerud")
data <- linnerud$exercise
pca.result <- pca(data, ncomp = 3, center = FALSE, scale = FALSE)
# loading vectors
pca.result$loadings$X


## ---- eval = TRUE, echo = FALSE----------------------
# loadings
loadings.PCA = pca.result$loadings$X
rownames(loadings.PCA) = colnames(data)
colnames(loadings.PCA) = paste('Dim', 1:3)

# components
components.PCA = pca.result$variates$X
rownames(components.PCA) = rownames(data)
colnames(components.PCA) = paste('PC', 1:3)


## ----------------------------------------------------
data[1,]


## ---- eval = FALSE-----------------------------------
## plot(pca.result$variates$X[,1], pca.result$variates$X[,2],
##      xlab = 'PC1', ylab = 'PC2')


## ----linnerud-PC, eval = FALSE, echo = FALSE, results = 'hide', fig.show = 'hide'----
## # this is a bit fiddly but basically I saved the table as a png, then include as a figure'. Now putting everythin as eval = FALSE
## # save table as image
## kable_input = knitr::kable(data.frame(components.PCA[,1:2]), row.names = 1, format = "latex", digits = 2)
## knitr::kable_as_image(kable_input, filename = 'Figures/Part2/linnerudPC12', file_format = "png")


## ----figPC12, eval = FALSE, echo = FALSE, results = 'hide', fig.show = 'hide', fig.path = 'Figures/Part2/'----
## # save figure as image
## plot(components.PCA[,1], components.PCA[,2], xlab = 'PC1', ylab = 'PC2', type = 'n', main = 'Linnerud exercise data, PC1 vs. PC2')
## text(components.PCA[,1], components.PCA[,2], rownames(data), col = c(rep('blue',3), rep('gray', nrow(data) -3)), cex = 1.2)


## ----tabPC12, echo = FALSE, fig.show="hold", fig.cap='(ref:tabPC12)', out.width='45%', fig.asp=1, fig.subcap=c('', ''), fig.align='center'----
# include both here but need to work out sizing issues
knitr::include_graphics(c("Figures/Part2/linnerudPC12.png", "Figures/Part2/figPC12-1.pdf"))


## ----svd,eval=TRUE, echo=FALSE, fig.cap='(ref:svd)', fig.align="center", out.width = '70%'----
knitr::include_graphics("Figures/Part2/SingleValDecomp.pdf", auto_pdf = TRUE)


## ---- eval = TRUE, results = 'hide'------------------
# Components:
T.comp <- svd(data)$u  %*% diag(svd(data)$d)


## ----linnerud-Tcomp, echo = FALSE--------------------
rownames(T.comp) <- rownames(data)
colnames(T.comp) <- paste('PC', 1:Matrix::rankMatrix(data))
knitr::kable(data.frame(T.comp), digits = 2, caption = 'Linnerud exercise data. Principal components calculated with SVD.')


## ---- out.width='50%'--------------------------------
plot(T.comp[,1], T.comp[,2], main = 'PCA SVD')


## ---- eval = TRUE, results = 'hide'------------------
# Loading vectors:
svd(data)$v


## ----linnerud-loading-vect, echo = FALSE-------------
loading.vect <- svd(data)$v
rownames(loading.vect) <- colnames(data)
colnames(loading.vect) <- paste('Dim', 1:Matrix::rankMatrix(data))
knitr::kable(data.frame(loading.vect), digits = 2, caption = 'Linnerud exercise data. Loading vectors calculated with SVD.')


## ---- eval = TRUE, results = 'hide'------------------
# Variance explained by components:
svd(data)$d/sqrt(nrow(data) - 1)


## ----linnerud-varex, echo = FALSE--------------------
var.expl <- t(as.matrix(svd(data)$d/sqrt(nrow(data) - 1)))
colnames(var.expl) <- paste('Comp', 1:Matrix::rankMatrix(data))
knitr::kable(data.frame(var.expl), caption = 'Linnerud exercise data. Variance explained per component calculated with SVD.', digits = 2)


## ---- eval = FALSE, echo = TRUE----------------------
## # Plots of the fitted linear regression line with no intercept
## 
## plot(T.comp[,1], data$Chins)
## abline(lm(data$Chins ~ T.comp[,1]-1))
## 
## plot(T.comp[,1], data$Situps)
## abline(lm(data$Situps ~ T.comp[,1]-1))
## 
## plot(T.comp[,1], data$Jumps)
## abline(lm(data$Jumps ~ T.comp[,1]-1))


## ----localreg, echo=FALSE, fig.keep= 'last', fig.cap='(ref:localreg)', fig.cap = 'In the NIPALS algorithm, the loading vector for a given variable is equal to the slope of the local regression of the variable onto the principal component.', fig.align="center", out.width = '80%', fig.height=4----
# Generate figures
par(mfrow=c(1,3))
plot(T.comp[,1], data$Chins, main = 'Chins',
     xlab = 'PC1', ylab = 'Weight', pch = 16)
abline(lm(data$Chins ~ T.comp[,1]-1), col = color.mixo(1))
text(238, 1, 'Chins = a1 * PC1', col = color.mixo(1), font = 2)

plot(T.comp[,1], data$Situps, main = 'Situps',
     xlab = 'PC1', ylab = 'Situps', pch = 16)
abline(lm(data$Situps ~ T.comp[,1]-1), col = color.mixo(2))
text(220, 50, 'Situps = a2 * PC1', col = color.mixo(2), font = 2)

plot(T.comp[,1], data$Jumps, main = 'Jumps',
     xlab = 'PC1', ylab = 'Jumps', pch = 16)
abline(lm(data$Jumps ~ T.comp[,1]-1), col = color.mixo(4))
text(220, 25, 'Jumps = a3 * PC1', col = color.mixo(4), font = 2)
par(mfrow=c(1,1))


## ---- eval = FALSE-----------------------------------
## # Extract each coefficient value
## a1 <- coefficients(lm(data$Weight ~ T.comp[,1] -1))
## a2 <- coefficients(lm(data$Waist ~ T.comp[,1] -1))
## a3 <- coefficients(lm(data$Pulse ~ T.comp[,1] -1))
## # combine the coefficients into a and norm a
## a <- c(a1,a2,a3)
## a/crossprod(a)


## ----linnerud-slopes, echo = FALSE-------------------
a1 <- coefficients(lm(data[,1] ~ T.comp[,1] -1))
a2 <- coefficients(lm(data[,2] ~ T.comp[,1] -1))
a3 <- coefficients(lm(data[,3] ~ T.comp[,1] -1))
a <- c(a1,a2,a3)

kable_input = as.matrix(c(a)/crossprod(c(a)))
rownames(kable_input) = colnames(data)
colnames(kable_input) = 'Slope'
knitr::kable(data.frame(kable_input), digits = 2, caption = 'In the NIPALS algorithm, we obtain the loading vector for the first dimension by calculating the slopes from the local regressions of each variable onto the first principal component.')

