## ---- message=FALSE, warning=FALSE-------------------
library(mixOmics)
data(nutrimouse)
X <- nutrimouse$lipid
pca.lipid <- pca(X, ncomp = 2)


## ---- eval = FALSE-----------------------------------
## plotIndiv(pca.lipid, title = 'PCA on Nutrimouse lipid data')


## ---- eval= FALSE------------------------------------
## plotIndiv(pca.lipid, group = nutrimouse$diet,
##           pch = nutrimouse$genotype,
##           legend = TRUE, legend.title = 'Diet',
##           legend.title.pch = 'Genotype',
##           title = 'PCA on Nutrimouse lipid data')


## ----plotIndiv-pca1, echo = FALSE, results = 'hide', fig.show = 'hide', fig.path = 'Figures/Part2/'----
plotIndiv(pca.lipid, title = 'PCA on Nutrimouse lipid data')


## ----plotIndiv-pca2, echo = FALSE, results = 'hide', fig.show = 'hide', fig.path = 'Figures/Part2/'----
plotIndiv(pca.lipid, group = nutrimouse$diet, pch = nutrimouse$genotype,
              legend = TRUE, legend.title = 'Diet', legend.title.pch = 'Genotype',
          title = 'PCA on Nutrimouse lipid data')


## ----plotindiv-pca, echo=FALSE, eval=TRUE, fig.cap='(ref:plotindiv-pca)', fig.align="center", out.width = '50%', fig.height=4, fig.ncol = 2, fig.subcap=c('', '')----
knitr::include_graphics(c("Figures/Part2/plotIndiv-pca1-1.pdf", "Figures/Part2/plotIndiv-pca2-1.pdf"))


## ---- fig.show = 'hide'------------------------------
X <- nutrimouse$lipid
Y <- nutrimouse$gene
pls.nutri <- pls(X, Y, ncomp = 2)


## ----nutri-PLS1, fig.cap='(ref:nutri-PLS1)', out.width='40%'----
plotIndiv(pls.nutri, group = nutrimouse$diet, 
          pch = nutrimouse$genotype,
          title = 'PLS on Nutrimouse lipid and gene data')


## ----nutri-PLS2, fig.cap='(ref:nutri-PLS2)', out.width='40%'----
plotIndiv(pls.nutri, group = nutrimouse$diet, pch = nutrimouse$genotype,
          rep.space = 'XY-variate',
          title = 'PLS on Nutrimouse lipid and gene data')


## ---- eval = FALSE-----------------------------------
## pls.nutri <- pls(X, Y, ncomp = 3)
## plotIndiv(pls.nutri, group = nutrimouse$diet,
##           pch = c('sphere', 'octa')[nutrimouse$genotype],
##           rep.space = 'XY-variate', style = '3d')


## ---- eval = FALSE, echo = FALSE---------------------
## # Command line to save the plot
## library(rgl)
## pls.nutri <- pls(X, Y, ncomp = 3)
## plotIndiv(pls.nutri, group = nutrimouse$diet,
##           pch = c('sphere', 'octa')[nutrimouse$genotype],
##           cex = 0.5,
##           axes.box = 'both',
##           rep.space = 'XY-variate',
##           style = '3d')
## rgl.postscript('Figures/Part2/3dplot.pdf', fmt = "pdf")


## ----plotindiv-3d, echo=FALSE, eval=TRUE, fig.cap='(ref:plotindiv-3d)', fig.align="center", out.width = '40%', fig.height=4----
knitr::include_graphics(c("Figures/Part2/3dplot.pdf"))


## ----plotIndiv-ellipse, fig.cap='(ref:plotIndiv-ellipse)', fig.align="center", out.width = '60%', fig.height=4----
plotIndiv(pls.nutri, group = nutrimouse$genotype, ellipse = TRUE)


## ----pls-arrow, fig.cap='(ref:pls-arrow)', out.width='40%', fig.asp=1, fig.ncol = 1, fig.align='center'----
plotArrow(pls.nutri,
          group = nutrimouse$genotype,
          legend = TRUE,
          legend.title = 'Genotype') 


## ----load1, fig.cap='(ref:load1)', out.width='35%', fig.asp=1, fig.ncol = 1, fig.align='center'----
plotLoadings(pca.lipid)


## ----load2, fig.cap='(ref:load2)', out.width='40%', fig.asp=1, fig.ncol = 1, fig.align='center'----
plotLoadings(pls.nutri, 
             subtitle = c('lipids on Dim 1', 'genes on Dim 1'))


## ----load3, fig.cap='(ref:load3)', out.width='35%', fig.asp=1, fig.ncol = 1, fig.align='center'----
# PLS-DA on the lipid data
data(nutrimouse)
plsda.lipid <- plsda(nutrimouse$lipid, nutrimouse$genotype)
plotLoadings(plsda.lipid, contrib = 'max', method = 'median')


## ----corcircplot,eval=TRUE, echo=FALSE, fig.cap='(ref:corcircplot)', out.width='50%', fig.ncol = 2, fig.subcap=c('', ''), fig.align='center'----
knitr::include_graphics(c("Figures/Part2/fig-CC1.pdf", "Figures/Part2/fig-CC2.pdf"))


## ---- eval = FALSE-----------------------------------
## scale.pca.lipid <- pca(X, ncomp = 3, center = TRUE, scale = TRUE)
## plotVar(scale.pca.lipid,
##         title = 'Nutrimouse lipid, Components 1 and 2')
## plotVar(scale.pca.lipid, comp = c(1,3),
##         title = 'Nutrimouse lipid, Components 1 and 3')


## ---- echo = FALSE-----------------------------------
scale.pca.lipid <- pca(X, ncomp = 3, center = TRUE, scale = TRUE)

# comp 1-2
save.object <- plotVar(scale.pca.lipid, title = 'Nutrimouse lipid, Components 1 and 2', plot = FALSE)
index.x <- which(abs(save.object$x) > 0.8 & save.object$y > 0)
index.y <- which(save.object$y > 0.7 | save.object$y < -0.8)

color.var <- c(rep(color.mixo(3), ncol(X)))
cex.var <- c(rep(4, ncol(X)))
color.var[index.x] <- color.mixo(1)
color.var[index.y] <- color.mixo(5)

names(color.var) = names(cex.var) = colnames(X)
color.var[c('C16.0', 'C18.2n.6')] = color.mixo(2)
color.var[c('C16.1n.7', 'C14.0', 'C18.0')] = color.mixo(1)
color.var[c('C20.5n.3', 'C22.5n.3','C22.4n.6', 'C22.5n.6')] = color.mixo(5)

cex.var[c(index.x, index.y)] = 5
cex.var[c('C16.0', 'C18.2n.6','C20.5n.3', 'C18.0', 'C22.5n.3','C22.4n.6', 'C22.5n.6')] = 5


## ----plotVar-pca, echo = FALSE, fig.cap='(ref:plotVar-pca)', fig.align="center", out.width = '45%', fig.ncol = 2, fig.subcap=c('', '')----
# comp 1-2
plotVar(scale.pca.lipid, comp= c(1,2), 
        title = 'Nutrimouse lipid, Components 1 and 2', 
        col = list(color.var), cex = list(cex.var))

# comp 1-3
plotVar(scale.pca.lipid, comp = c(1,3), 
        title = 'Nutrimouse lipid, Components 1 and 3', 
        col = list(color.var), cex = list(cex.var))


## ---- eval = FALSE-----------------------------------
## plotVar(pls.nutri, var.names = c(TRUE, TRUE),
##         title = 'Nutrimouse, PLS no cutoff')
## 
## plotVar(pls.nutri, var.names = c(TRUE, TRUE),
##         cutoff = 0.5,
##         title = 'Nutrimouse, PLS with cutoff', legend = TRUE)


## ----plotvar-pls, echo = FALSE, fig.cap='(ref:plotvar-pls)', out.width = '45%', fig.ncol = 2, fig.subcap=c('', '')----
X <- nutrimouse$lipid
Y <- nutrimouse$gene
pls.nutri <- pls(X, Y, ncomp = 2)

color.var.X = c(rep('gray10', ncol(X)))
color.var.Y = c(rep('darkgray', ncol(Y)))

cex.var.X = c(rep(2, ncol(X)))
cex.var.Y = c(rep(2, ncol(Y)))

names(color.var.X) = names(cex.var.X) = colnames(X)
names(color.var.Y) = names(cex.var.Y) = colnames(Y)
color.var.X[c("C20.3n.6", "C18.0", "C22.6n.3", "C16.0", "C20.3n.9", "C16.1n.9", "C18.1n.9")] = color.mixo(4)
color.var.Y[c("GSTpi2", "SPI1.1", "HPNCL", "Lpin2", "SR.BI", "FAT", "UCP2")] = color.mixo(5)


cex.var.X[c("C20.3n.6", "C18.0", "C22.6n.3", "C16.0", "C20.3n.9", "C16.1n.9", "C18.1n.9")] = 5
cex.var.Y[c("GSTpi2", "SPI1.1", "HPNCL", "Lpin2", "SR.BI", "FAT", "UCP2")] = 5


plotVar(pls.nutri, var.names = c(TRUE, TRUE), title = 'Nutrimouse, PLS no cutoff', col = list(color.var.X, color.var.Y), cex = list(cex.var.X, cex.var.Y))


plotVar(pls.nutri, var.names = c(TRUE, TRUE), cutoff = 0.5,
        title = 'Nutrimouse, PLS with cutoff', legend = FALSE,
        col = list(color.var.X, color.var.Y), cex = list(cex.var.X, cex.var.Y))


## ----biplot-pca, fig.cap='(ref:biplot-pca)', out.width = '40%', fig.ncol = 2, fig.subcap=c('', '')----
biplot(scale.pca.lipid)
plotIndiv(scale.pca.lipid, group = nutrimouse$diet, 
          pch = nutrimouse$genotype,
          legend = TRUE, legend.title = 'Diet', 
          legend.title.pch = 'Genotype',
          title = 'PCA on Nutrimouse lipid data')


## ----network1, echo = FALSE, results = 'hide', fig.show = 'hide', fig.path = 'Figures/Part2/'----
network(pls.nutri,
        color.node = c("orange","lightblue"),
        save = 'pdf', name.save = 'Figures/Part2/network1')


## ----network2, echo = FALSE, results = 'hide', fig.show = 'hide', fig.path = 'Figures/Part2/'----
network(pls.nutri, color.node = c("orange","lightblue"),
        cutoff = 0.55,
        save = 'pdf', name.save = 'Figures/Part2/network2')


## ----network-pls, echo=FALSE, eval=TRUE, fig.cap='(ref:network-pls)', fig.align="center", out.width = '50%', fig.height=4, fig.ncol = 2, fig.subcap=c('', '')----
knitr::include_graphics(c("Figures/Part2/network1.pdf", "Figures/Part2/network2.pdf"))


## ----eval = FALSE------------------------------------
## network(pls.nutri, color.node = c("orange","lightblue"))
## 
## network(pls.nutri, color.node = c("orange","lightblue"),
##         cutoff = 0.55)


## ---- eval = FALSE-----------------------------------
## library(igraph)
## network.res <- network(pls.nutri)
## write.graph(network.res$gR, file = "network.gml", format = "gml")


## ---- eval = FALSE-----------------------------------
## network.res <- network(pls.nutri, save = 'jpeg', name.save = 'mynetwork')


## ---- eval = FALSE-----------------------------------
## network.res <- network(pls.nutri)
## network.res$M


## ---- echo = TRUE, eval = FALSE----------------------
## # On component 1:
## cim(pls.nutri, xlab = "genes", ylab = "lipids", comp = 1)
## # Default option: all components
## cim(pls.nutri, xlab = "genes", ylab = "lipids")


## ----cim1, echo = FALSE, results = 'hide', fig.show = 'hide', fig.path = 'Figures/Part2/'----
cim(pls.nutri, xlab = "genes", ylab = "lipids",
    comp = 1,
    save = 'pdf', name.save =  'Figures/Part2/cim1'
    )


## ----cim2, echo = FALSE, results = 'hide', fig.show = 'hide', fig.path = 'Figures/Part2/'----
# Default option: all components
cim(pls.nutri, xlab = "genes", ylab = "lipids",
    save = 'pdf', name.save =  'Figures/Part2/cim2'
    )


## ----cim-pls, echo=FALSE, eval=TRUE, fig.cap='(ref:cim-pls)', out.width = '40%', fig.ncol = 2, fig.subcap=c('', '')----
knitr::include_graphics(c("Figures/Part2/cim1.pdf", "Figures/Part2/cim2.pdf"))


## ----circos, echo = FALSE, fig.cap='(ref:circos)', out.width='50%'----
knitr::include_graphics("Figures/Part2/CircosPlot.pdf")

