## ----perf-overview, eval=TRUE, echo=FALSE, fig.cap='(ref:perf-overview)', out.width='100%', fig.asp=1----
knitr::include_graphics("Figures/Part2/CrossValidation.pdf")


## ----tune-comp, echo = FALSE, eval = FALSE, results = 'hide', fig.show = 'hide', fig.path = 'Figures/Part2/'----
## # I put eval = FALSE to skip computational time
## data(srbct)
## X <- srbct$gene
## Y <- srbct$class
## ncomp = 10
## plsda.srbct <- plsda(X, Y, ncomp = ncomp)
## 
## set.seed(45)
## t1 = Sys.time()
## error <- perf(plsda.srbct, validation = "Mfold", folds = 3,
## dist = "max.dist", nrepeat = 10, progressBar = FALSE)
## t2 = Sys.time()
## #t2 - t1
## plot(error, sd = TRUE)
## 
## #error$choice.ncomp


## ----tune-component, fig.cap='(ref:tune-component)', out.width='40%', fig.asp=1, fig.ncol = 1, fig.align='center', echo = FALSE----
knitr::include_graphics("Figures/Part2/tune-comp-1.pdf")


## ----tune-keepX, echo = FALSE, eval = FALSE, results = 'hide', fig.show = 'hide', fig.path = 'Figures/Part2/'----
## # I put eval = FALSE to skip computational time
## data(srbct)
## X <- srbct$gene
## Y <- srbct$class
## ncomp = 5
## list.keepX = c(seq(5, 50, 5), seq(100, 500, 100))
## 
## set.seed(45)
## t1 = Sys.time()
## error.keepX <- tune.splsda(X, Y, ncomp = ncomp, test.keepX = list.keepX, validation = "Mfold", folds = 3,
## dist = "max.dist", nrepeat = 10, progressBar = FALSE)
## t2 = Sys.time()
## t2 - t1
## plot(error.keepX)
## 
## #error.keepX$choice.ncomp$ncomp
## #error.keepX$choice.keepX


## ----tune-varkeepX, fig.cap='(ref:tune-varkeepX)', out.width='50%', fig.asp=1, fig.ncol = 1, fig.align='center', echo = FALSE----
knitr::include_graphics("Figures/Part2/tune-keepX-1.pdf")


## ----errorrate, echo = FALSE-------------------------
library(mixOmics)
data(srbct)
X <- srbct$gene
Y <- srbct$class
srbct.splsda = splsda(X, Y, ncomp = 3, keepX = c(30, 300, 50))
set.seed(45)  # setting the seed but not mentioning the actual results
perf.splsda = perf(srbct.splsda, validation = "Mfold", folds = 3,
dist = "max.dist", nrepeat = 10, progressBar = FALSE)
error.per.class = perf.splsda$error.rate.class

knitr::kable(error.per.class, caption = 'Example of performance output: classification error rate (ER) per class and per component allows us to understand which tumour subtype class EWS, BL, NB or RMS is misclassified. On Component 2, NB is still difficult to classify until a third component is added in the model.', digits = 2)


## ----perf-stability, echo = FALSE--------------------
freq.comp3 = t(perf.splsda$features$stable$comp3[1:10])
knitr::kable(freq.comp3, caption = 'Example of performance output: frequency of occurrence for each gene  selected across the repeated CV folds. This output shows which genes are consistently selected in the signature, and can therefore be prioritised for (experimental) validation.', digits = 2)


## ----predict-continuous, echo = FALSE----------------
data(srbct)
X <- srbct$gene
Y <- srbct$class
set.seed(34)  # so that we have the same results
train_rows <- sample(1:nrow(X), .80*nrow(X))
# training ad test sets
X.train <- X[train_rows, ]
X.test <- X[-train_rows, ]
Y.train <- Y[train_rows]
Y.test <- Y[-train_rows]

splsda.train <- splsda(X.train, Y.train, ncomp = 3, keepX=c(50,50,50))
splsda.predict <- predict(splsda.train, X.test)
knitr::kable(splsda.predict$predict[,,1], caption = 'Example of a prediction output for classification: the test samples are arranged in rows with their known subtypes indicated as rownames. Their prediction is calculated for each subtype class in columns as a continuous value, even if the original classes are categorical values.', digit = 3)


## ----predict-distances, echo = FALSE-----------------
mat.pred = data.frame(max.dist = splsda.predict$class$max.dist[, 'comp1'], centroid.dist = splsda.predict$class$centroids.dist[, 'comp1'], mahalanobis.dist = splsda.predict$class$centroids.dist[, 'comp1'])
knitr::kable(mat.pred, caption = 'Example of a prediction output after applying one of the three distances (in columns): the test samples are arranged in rows, and their prediction score is assigned a class membership. The real class of each sample is indicated in the row names, illustrating several misclassifications.')


## ---- echo = FALSE-----------------------------------
plsda.srbct <- plsda(X, Y, ncomp = 2)


## ----background-plsda-maxdist, echo = FALSE, results = 'hide', fig.show = 'hide', fig.path = 'Figures/Part2/'----
background <- background.predict(plsda.srbct,comp.predicted=2, dist = "max.dist")#, xlim = c(-40,40), ylim = c(-30,30))
plotIndiv(plsda.srbct, comp = 1:2,
          group = srbct$class, ind.names = FALSE, title = "Maximum distance",
          ellipse = FALSE, legend = FALSE,  background = background,
          size.title = rel(2.5), size.xlabel = rel(1.5), size.ylabel = rel(1.5), size.axis = rel(1.1),cex=3,
          point.lwd=2,
          size.legend = rel(1.5), size.legend.title = rel(1.5)
          )


## ----background-plsda-centrodist, echo = FALSE, results = 'hide', fig.show = 'hide', fig.path = 'Figures/Part2/'----
background <- background.predict(plsda.srbct,comp.predicted=2, dist = "centroids.dist")
plotIndiv(plsda.srbct, comp = 1:2,
          group = srbct$class, ind.names = FALSE, title = "Centroids distance",
          ellipse = FALSE, legend = FALSE,  background = background,
          size.title = rel(2.5), size.xlabel = rel(1.5), size.ylabel = rel(1.5), size.axis = rel(1.1),cex=3,
          point.lwd=2,
          size.legend = rel(1.5), size.legend.title = rel(1.5)
          )


## ----background-plsda-mahaldist, echo = FALSE, results = 'hide', fig.show = 'hide', fig.path = 'Figures/Part2/'----
background <- background.predict(plsda.srbct,comp.predicted=2, dist = "mahalanobis.dist")
plotIndiv(plsda.srbct, comp = 1:2,
          group = srbct$class, ind.names = FALSE, title = "Mahalanobis distance",
          ellipse = FALSE, legend = FALSE,  background = background,
          size.subtitle = rel(2.5), size.xlabel = rel(1.5), size.ylabel = rel(1.5), size.axis = rel(1.1),cex=3,
          point.lwd=2,
          size.legend = rel(1.5), size.legend.title = rel(1.5)
          )


## ----predict-dist, echo=FALSE, eval=TRUE, fig.cap='(ref:predict-dist)', fig.align="center", out.width = '30%', fig.height=4, fig.ncol = 3, fig.subcap=c('', '', '')----
knitr::include_graphics(c("Figures/Part2/background-plsda-maxdist-1.pdf", "Figures/Part2/background-plsda-centrodist-1.pdf", "Figures/Part2/background-plsda-mahaldist-1.pdf"))


## ----background-plsda-maxdist-comp1, echo = FALSE, results = 'hide', fig.show = 'hide', fig.path = 'Figures/Part2/'----
background <- background.predict(plsda.srbct,comp.predicted=1, dist = "max.dist")#, xlim = c(-40,40), ylim = c(-30,30))
plotIndiv(plsda.srbct, comp = 1:2,
          group = srbct$class, ind.names = FALSE, title = "Maximum distance",
          ellipse = FALSE, legend = FALSE,  background = background,
          size.title = rel(2.5), size.xlabel = rel(1.5), size.ylabel = rel(1.5), size.axis = rel(1.1),cex=3,
          point.lwd=2,
          size.legend = rel(1.5), size.legend.title = rel(1.5)
          )


## ----background-plsda-centrodist-comp1, echo = FALSE, results = 'hide', fig.show = 'hide', fig.path = 'Figures/Part2/'----
background <- background.predict(plsda.srbct,comp.predicted=1, dist = "centroids.dist")
plotIndiv(plsda.srbct, comp = 1:2,
          group = srbct$class, ind.names = FALSE, title = "Centroids-based distances",
          ellipse = FALSE, legend = FALSE,  background = background,
          size.title = rel(2.5), size.xlabel = rel(1.5), size.ylabel = rel(1.5), size.axis = rel(1.1),cex=3,
          point.lwd=2,
          size.legend = rel(1.5), size.legend.title = rel(1.5)
          )


## ----predict-dist-comp1, echo=FALSE, eval=TRUE, fig.cap='(ref:predict-dist-comp1)', fig.align="center", out.width = '25%', fig.height=4, fig.ncol = 2, fig.subcap=c('', '')----
knitr::include_graphics(c("Figures/Part2/background-plsda-maxdist-comp1-1.pdf", "Figures/Part2/background-plsda-centrodist-comp1-1.pdf")) 

