## ---- eval = TRUE, echo = TRUE-----------------------
library(mixOmics)
data(linnerud)
# Concatenate exercise and physiological variables
data <- data.frame(linnerud$exercise, linnerud$physiological)

# If we center per variable, then calculate mean and SD per variable 
# (rounded values):
data.center <- scale(data, center = TRUE, scale = FALSE)
round(apply(data.center, 2, mean),2)
round(apply(data.center, 2, sd),2)

# If we center and scale per variable, then calculate mean and SD per variable 
# (rounded values):
data.center.scale <- scale(data, center = TRUE, scale = TRUE)
round(apply(data.center.scale, 2, mean),2)
round(apply(data.center.scale, 2, sd),2)


## ----center-scale, echo=FALSE, eval=TRUE, fig.cap='(ref:center-scale)', fig.align="center", out.width = '33%', fig.height=6, fig.ncol = 3, fig.subcap=c('', '', '')----

library(ggplot2)
data2 <- stack(data.frame(scale(data, center = FALSE, scale = FALSE)))
colnames(data2) <- c('values', 'variable')
ggplot(data2, aes(x = variable, y = values, shape = variable, color = variable)) + 
  geom_jitter(position=position_jitter(0.2), cex=rel(2)) +
  stat_summary(fun.data=mean_sdl,
                 geom="pointrange", color="blue") +
  scale_shape_manual(values=c(1,2, 16, 17, 19, 22, 23)) +
  scale_color_manual(values=color.mixo(1:6)) +
  labs(y = 'values') +
  theme(legend.position="none", axis.text.x = element_text(size=12),
        axis.title.x = element_text(size=14), axis.title.y = element_text(size=14))

data2 <- stack(data.frame(scale(data, center = TRUE, scale = FALSE)))
colnames(data2) <- c('values', 'variable')
ggplot(data2, aes(x = variable, y = values, shape = variable, color = variable)) + 
  geom_jitter(position=position_jitter(0.2), cex=rel(2)) +
  stat_summary(fun.data=mean_sdl,
                 geom="pointrange", color="blue") +
  scale_shape_manual(values=c(1,2, 16, 17, 19, 22, 23)) +
  scale_color_manual(values=color.mixo(1:6)) +
  labs(y = 'centered values') +
  theme(legend.position="none", axis.text.x = element_text(size=12),
        axis.title.x = element_text(size=14), axis.title.y = element_text(size=14))

data2 <- stack(data.frame(scale(data, center = TRUE, scale = TRUE)))
colnames(data2) <- c('values', 'variable')
ggplot(data2, aes(x = variable, y = values, shape = variable, color = variable)) + 
  geom_jitter(position=position_jitter(0.2), cex=rel(2)) +
  stat_summary(fun.data=mean_sdl,
                 geom="pointrange", color="blue") +
  scale_shape_manual(values=c(1,2, 16, 17, 19, 22, 23)) +
  scale_color_manual(values=color.mixo(1:6)) +
  labs(y = 'centered and scaled values') +
  theme(legend.position="none", axis.text.x = element_text(size=12),
        axis.title.x = element_text(size=14), axis.title.y = element_text(size=14))


## ---- eval = FALSE-----------------------------------
## pca.linnerud <- pca(data, center = FALSE, scale = FALSE)
## plotIndiv(pca.linnerud)
## plotVar(pca.linnerud)


## ----centerscale1, echo = FALSE, fig.cap='(ref:centerscale1)', fig.align="center", out.width = '33%', fig.ncol = 3, fig.subcap=c('', '', '')----
pca.linnerud <- pca(data, center = FALSE, scale = FALSE)
color.indiv <- c(rep('grey', nrow(data)))
color.indiv[10] <- color.mixo(1)
color.indiv[17] <- color.mixo(2)
color.indiv[c(1,5,3)] <- color.mixo(4)
boxplot(t(data), col = color.indiv)
plotIndiv(pca.linnerud, title = 'Linnnerud PCA: no centering nor scaling', col = color.indiv, cex = 6)
plotVar(pca.linnerud, title = '')


## ---- eval = FALSE-----------------------------------
## pca.linnerud <- pca(data, center = TRUE, scale = FALSE)


## ----centerscale2, echo = FALSE, fig.cap='(ref:centerscale2)', fig.align="center", out.width = '45%', fig.ncol = 2, fig.subcap=c('', '')----
pca.linnerud <- pca(data, center = TRUE, scale = FALSE)
plotIndiv(pca.linnerud, title = 'Linnnerud PCA: center', col = color.indiv, cex = 6)
plotVar(pca.linnerud, title = '')


## ----eval = FALSE------------------------------------
## pca.linnerud <- pca(data, center = TRUE, scale = TRUE)


## ----centerscale3, echo = FALSE, fig.cap='(ref:centerscale3)', fig.align="center", out.width = '45%', fig.ncol = 2, fig.subcap=c('', '')----
pca.linnerud <- pca(data, center = TRUE, scale = TRUE)
plotIndiv(pca.linnerud, title = 'Linnnerud PCA: center and scale', 
          col = color.indiv, cex = 6)
plotVar(pca.linnerud, title = '')


## ---- eval = FALSE-----------------------------------
## ## Install BiocManager if not installed
## if (!requireNamespace("BiocManager", quietly = TRUE))
##     install.packages("BiocManager")
## ## Ensure the following returns TRUE, or follow Bioconductor guidelines
## BiocManager::valid()
## 
## ## Install mixOmics
## BiocManager::install('mixOmics')


## ---- eval = FALSE-----------------------------------
## BiocManager::install("mixOmicsTeam/mixOmics")


## ---- message=FALSE----------------------------------
library(mixOmics)


## ---- eval=FALSE-------------------------------------
## setwd("C:/path/to/my/data/")


## ---- eval = FALSE-----------------------------------
## # From csv file, the data set contains header information and row names of the
## # samples are in the first column
## data <- read.csv("my_data.csv", row.names = 1, header = TRUE)
## 
## # From txt file, the data set contains header information and row names of the
## # samples are in the first column
## data <- read.table("my_data.txt", row.names = 1, header = TRUE)


## ---- results='hide'---------------------------------
Y <- data[,1]

# Check this is a vector
is.vector(Y)

# If not, you need to set Y as a vector
Y <- as.vector(Y)

# Then remove the response vector from the data for analysis
data2 <- data[, -1]


## ---- results='hide'---------------------------------
# 10 cases and 10 controls in this order
Y <- c(rep('Case', 10), rep('Control', 10))
# Set as factor, option is to define the level in the order we wish
Y <- factor(Y, levels = c('Case', 'Control'))
# Check:
summary(Y)


## ----mix-overview, echo=FALSE, eval=TRUE, message=FALSE, fig.cap='(ref:mix-overview)', out.width = '50%'----
library(mixOmics)
coul <- color.mixo(1:3)

plot(0, type="n", xlim=c(0,100), ylim=c(0,100), axes=FALSE,
     xlab="",ylab="", main="mixOmics methods overview", cex.main = 1.2)
box()

# PCA
rect(xleft = 20, ybottom = 75, xright = 40, ytop = 95, col=coul[1])
text(5, 85, "PCA")

# PLS-DA
rect(xleft = 20, ybottom = 50, xright = 40, ytop = 70, col=coul[1])
rect(xleft = 43, ybottom = 50, xright = 45, ytop = 70, col=coul[2])
text(5, 60, "PLS-DA", col = coul[2])

# PLS
rect(xleft = 20, ybottom = 25, xright = 40, ytop = 45, col=coul[1])
rect(xleft = 43, ybottom = 25, xright = 60, ytop = 45, col=coul[1])
text(5, 35, "PLS")

# DIABLO
rect(xleft = 20, ybottom = 0, xright = 40, ytop = 20, col=coul[1])
rect(xleft = 43, ybottom = 0, xright = 60, ytop = 20, col=coul[1])
points(x=61, y=10, pch=16, col=coul[3], cex=0.5)
points(x=62.5, y=10, pch=16, col=coul[3], cex=0.5)
points(x=64, y=10, pch=16, col=coul[3], cex=0.5)
rect(xleft = 65, ybottom = 0, xright = 80, ytop = 20, col=coul[1])
rect(xleft = 85, ybottom = 0, xright = 88, ytop = 20, col=coul[2])
text(5, 10, "DIABLO", col = coul[2])

# legend
rect(xleft = 75, ybottom = 95, xright = 77, ytop = 97, col=coul[1])
text(90, 96, "Quantitative", cex=0.75)
rect(xleft = 75, ybottom = 90, xright = 77, ytop = 92, col=coul[2])
text(90, 91, "Qualitative", cex=0.75)


## ---- results='hide'---------------------------------
dim(data2)
#[1] 20 5


## ---- eval = FALSE, results='hide'-------------------
## View(data2)            # a spreadsheet style tab opens with the entire data
## head(data2)            # returns the first 6 rows of data to the console


## ----------------------------------------------------
match(rownames(linnerud$physiological), rownames(linnerud$exercise))

