## ----pca-outline, eval=TRUE, echo=FALSE, fig.cap='(ref:pca-outline)', fig.align="center", out.width = '70%'----
knitr::include_graphics("Figures/Part3/OutlineofPCA.pdf")


## ----spca-outline, eval=TRUE, echo=FALSE, fig.cap='(ref:spca-outline)', fig.align="center", out.width = '70%'----
knitr::include_graphics("Figures/Part3/OutlineofsparsePCA.pdf")


## ----eval=TRUE, message=FALSE, warning=FALSE---------
library(mixOmics)
data(multidrug)
X <- multidrug$ABC.trans
dim(X) # Check dimensions of data


## ----------------------------------------------------
sum(is.na(X))  # Number of NAs


## ---- eval = FALSE, fig.show = 'hide', message = FALSE----
## result.pca.multi <- pca(X)     # 1 Run the method
## plotIndiv(result.pca.multi)    # 2 Plot the samples
## plotVar(result.pca.multi)      # 3 Plot the variables


## ---- eval = FALSE, fig.show = 'hide', message = FALSE----
## result.spca.multi <- spca(X, keepX = c(10, 20), ncomp = 2)
## plotIndiv(result.spca.multi)
## plotVar(result.spca.multi)


## ----screeplot-fig, fig.cap='(ref:screeplot-fig)'----
tune.pca.multi <- tune.pca(X, ncomp = 10, scale = TRUE)
plot(tune.pca.multi)
# tune.pca.multidrug$cum.var       # Outputs cumulative proportion of variance


## ----echo=TRUE, message=FALSE------------------------
final.pca.multi <- pca(X, ncomp = 3, center = TRUE, scale = TRUE)
# final.pca.multi  # Lists possible outputs


## ----------------------------------------------------
final.pca.multi$var.tot


## ----------------------------------------------------
final.pca.multi$prop_expl_var$X


## ---- eval = TRUE------------------------------------
final.pca.multi$cum.var


## ----echo=TRUE, message=FALSE------------------------
# Top variables on the first component only:
head(selectVar(final.pca.multi, comp = 1)$value)


## ----pca-ABCtrans-group, fig.cap='(ref:pca-ABCtrans-group)'----
plotIndiv(final.pca.multi,
          comp = c(1, 2),   # Specify components to plot
          ind.names = TRUE, # Show row names of samples
          group = multidrug$cell.line$Class,
          title = 'ABC transporters, PCA comp 1 - 2',
          legend = TRUE, legend.title = 'Cell line')


## ---- eval = FALSE-----------------------------------
## # Interactive 3D plot will load the rgl library.
## plotIndiv(final.pca.multi, style = '3d',
##            group = multidrug$cell.line$Class,
##           title = 'ABC transporters, PCA comp 1 - 3')


## ---- eval = FALSE-----------------------------------
## plotVar(final.pca.multi, comp = c(1, 2),
##         var.names = TRUE,
##         cex = 3,         # To change the font size
##         # cutoff = 0.5,  # For further cutoff
##         title = 'Multidrug transporter, PCA comp 1 - 2')


## ----pca-var-ABStrans-ccp, eval=TRUE, echo = FALSE, fig.cap='(ref:pca-var-ABStrans-ccp)'----
col.var <- c(rep(color.mixo(1), ncol(X)))
names(col.var) = colnames(X)
col.var[c('ABCE1', 'ABCB8')] = color.mixo(2)
col.var[c('ABCA8')] = color.mixo(4)
col.var[c('ABCC2')] = color.mixo(5)
col.var[c('ABCC12', 'ABCD2')] = color.mixo(6)

plotVar(final.pca.multi, comp = c(1, 2),
        var.names = TRUE,
        col = list(col.var),
        cex = 3,
        title = 'Multidrug transporter, PCA comp 1 - 2')


## ----pca-ABStrans-biplot, eval=TRUE, fig.cap='(ref:pca-ABStrans-biplot)'----
biplot(final.pca.multi, group = multidrug$cell.line$Class, 
       legend.title = 'Cell line')


## ----pca-ABCtrans-boxplot, eval=TRUE, fig.cap='(ref:pca-ABCtrans-boxplot)'----
ABCC2.scale <- scale(X[, 'ABCC2'], center = TRUE, scale = TRUE)

boxplot(ABCC2.scale ~
        multidrug$cell.line$Class, col = color.mixo(1:9),
        xlab = 'Cell lines', ylab = 'expression levels, scaled',
        par(cex.axis = 0.5), # Font size
        main = 'ABCC2 transporter')


## ----------------------------------------------------
grid.keepX <- c(seq(5, 30, 5))
# grid.keepX  # To see the grid

set.seed(30) # For reproducibility with this handbook, remove otherwise
tune.spca.result <- tune.spca(X, ncomp = 3, 
                              folds = 5, 
                              test.keepX = grid.keepX, nrepeat = 10) 

# Consider adding up to 50 repeats for more stable results
tune.spca.result$choice.keepX


## ----spca-tuning-ABStrans, fig.cap='(ref:spca-tuning-ABStrans)'----
plot(tune.spca.result)


## ----------------------------------------------------
# By default center = TRUE, scale = TRUE
keepX.select <- tune.spca.result$choice.keepX[1:2]

final.spca.multi <- spca(X, ncomp = 2, keepX = keepX.select)

# Proportion of explained variance:
final.spca.multi$prop_expl_var$X


## ----spca-ABCtrans-group, fig.cap='(ref:spca-ABCtrans-group)'----
plotIndiv(final.spca.multi,
          comp = c(1, 2),   # Specify components to plot
          ind.names = TRUE, # Show row names of samples
          group = multidrug$cell.line$Class,
          title = 'ABC transporters, sPCA comp 1 - 2',
          legend = TRUE, legend.title = 'Cell line')


## ----spca-ABCtrans-biplot, eval=TRUE, fig.cap='(ref:spca-ABCtrans-biplot)'----
biplot(final.spca.multi, group = multidrug$cell.line$Class, 
       legend =FALSE)


## ---- eval = FALSE-----------------------------------
## plotVar(final.spca.multi, comp = c(1, 2), var.names = TRUE,
##         cex = 3, # To change the font size
##         title = 'Multidrug transporter, sPCA comp 1 - 2')


## ----spca-var-ABStrans-ccp, eval=TRUE, fig.cap='(ref:spca-var-ABCtrans-ccp)', echo = FALSE----
col.var <- c(rep(color.mixo(1), ncol(X)))
names(col.var) <- colnames(X)
col.var[c("ABCA9", "ABCB5", "ABCC2","ABCD1")] <- color.mixo(4)

plotVar(final.spca.multi, comp = c(1, 2), var.names = TRUE,
        col = list(col.var), cex = 3, # To change the font size
        title = 'Multidrug transporter, sPCA comp 1 - 2')


## ----echo=TRUE, message=FALSE------------------------
# On the first component, just a head
head(selectVar(final.spca.multi, comp = 2)$value)


## ----spca-plotLoading, eval=TRUE, fig.cap='(ref:spca-plotLoading)'----
plotLoadings(final.spca.multi, comp = 2)


## ----plot-NA-rate------------------------------------
# Here, X.na is the compound data.
X.na <- multidrug$compound

# First, sum the number of missing values per variable.
sum.na.per.var <- apply(X.na, 2, function(x){sum(is.na(x))})

# A simple plot to show the NA rate per variable:
plot(sum.na.per.var/nrow(X), type = 'h',
     xlab = 'variable index', ylab = 'NA rate', main = 'NA rate per variable')

# These variables could be removed according to a threshold, e.g. 20%
remove.var <- which(sum.na.per.var/nrow(X) > 0.20)
X.na <- X.na[, -c(remove.var)]
dim(X.na) # Check the dimensions of the data

# Any additional information should also be updated to reflect the filtering, e.g.
compound.name.noNA <- multidrug$comp.name[-c(remove.var)]


## ----------------------------------------------------
sum(is.na(X.na)) / (length(X.na)) # Proportion of missing values


## ---- message = FALSE, fig.show= 'hide'--------------
# This might take some time - here 40s, depending on the size of the dataset.
# Reconstructed matrix from NIPALS:
X.nipals <- impute.nipals(X.na, ncomp = 10)


## ----------------------------------------------------
# Internally this function calls NIPALS but does not impute NAs
pca.with.na <- pca(X.na, ncomp = 3, center = TRUE, scale = TRUE)

# PCA on data imputed with NIPALS
pca.no.na <- pca(X.nipals, ncomp = 3, center = TRUE, scale = TRUE)


## ----------------------------------------------------
pca.with.na$cum.var
pca.no.na$cum.var


## ----plotindiv-pca-impute, fig.cap='(ref:plotindiv-pca-impute)', fig.ncol = 2, fig.subcap=c('', ''), out.width='50%'----
plotIndiv(pca.with.na, group = multidrug$cell.line$Class, legend = TRUE,
          title = 'PCA with missing values')

plotIndiv(pca.no.na, group = multidrug$cell.line$Class, legend = TRUE,
          title = 'PCA with NIPALS imputed missing values')


## ----------------------------------------------------
cor(pca.with.na$variates$X, pca.no.na$variates$X)

