## ----CCA-outline, echo=FALSE, fig.cap='(ref:CCA-outline)', out.width = '70%'----
knitr::include_graphics("Figures/Part3/CCA.pdf", auto_pdf = TRUE)


## ----------------------------------------------------
library(mixOmics)
data(nutrimouse)
X <- nutrimouse$gene
Y <- nutrimouse$lipid


## ---- eval = FALSE, fig.show = 'hide', message = FALSE----
## cca.result <- rcc(Y, X)     # 1 Run the method
## plotIndiv(cca.result)       # 2 Plot the samples
## plotVar(cca.result)         # 3 Plot the variables


## ---- eval = FALSE, message = FALSE------------------
## rcca.result <- rcc(X, Y, method = 'ridge', lambda1 = 0.5, lambda2 = 0.05)  # 1 run the method


## ---- eval = FALSE, message = FALSE------------------
## rcca.result <- rcc(X, Y, method = 'shrinkage') # 1 run the method


## ----eval = FALSE, fig.show = 'hide', message = FALSE----
## plotIndiv(rcca.result)       # 2 Plot the samples
## plotVar(rcca.result)         # 3 Plot the variables


## ---- message=FALSE, warning=FALSE-------------------
data(nutrimouse)
X.subset1 <- nutrimouse$lipid[, 1:10]
Y.subset1 <- nutrimouse$gene[, 1:10]
result1 <- rcc(X.subset1, Y.subset1)


## ----------------------------------------------------
X.subset2 <- nutrimouse$lipid    # All 21 lipids
Y.subset2 <- nutrimouse$gene[, 1:25]
result2 <- rcc(X.subset2, Y.subset2)


## ----FigCCA-cor-can1, eval = TRUE, echo = TRUE, results = 'hide', fig.show = 'hide', fig.path = 'Figures/Part3/'----
plot(result1, type = "barplot")


## ----FigCCA-cor-can2, eval = TRUE, echo = TRUE, results = 'hide', fig.show = 'hide', fig.path = 'Figures/Part3/'----
plot(result2, type = "barplot")


## ----CCA-cor-can, echo = FALSE, fig.cap='(ref:CCA-cor-can)', out.width='45%', fig.asp=1, fig.ncol = 2, fig.align='center', fig.subcap=c('', '')----
# include both here
knitr::include_graphics(c("Figures/Part3/FigCCA-cor-can1-1.png", "Figures/Part3/FigCCA-cor-can2-1.png"))


## ----FigCCA-plotvar1, eval = TRUE, echo = TRUE, results = 'hide', fig.show = 'hide', fig.path = 'Figures/Part3/'----
plotVar(result1)


## ----FigCCA-plotvar2, eval = TRUE, echo = TRUE, results = 'hide', fig.show = 'hide', fig.path = 'Figures/Part3/'----
plotVar(result2)


## ----CCA-plotvar, fig.cap='(ref:CCA-plotvar)', echo = FALSE, out.width='45%', fig.asp=1, fig.ncol = 2, fig.align='center', fig.subcap=c('', '')----
# include both here
knitr::include_graphics(c("Figures/Part3/FigCCA-plotvar1-1.png", "Figures/Part3/FigCCA-plotvar2-1.png"))


## ----------------------------------------------------
X <- nutrimouse$lipid
Y <- nutrimouse$gene
dim(X); dim(Y)

# Check indiv names are matching (not output here):
# head(cbind(rownames(X), rownames(Y)))


## ----rCCA-imgcor, fig.cap='(ref:rCCA-imgcor)', fig.width=10, fig.height=8, echo = TRUE----
imgCor(X, Y)


## ----rCCA-lambda, fig.cap='(ref:rCCA-lambda)'--------
grid1 <- seq(0, 0.2, length = 5)
grid2 <- seq(0.001, 0.2, length = 5)
cv.tune.rcc <- tune.rcc(X, Y, grid1 = grid1, grid2 = grid2, validation = "loo")
cv.tune.rcc


## ----------------------------------------------------
rcc.nutri <- rcc(X, Y, lambda1 = cv.tune.rcc$opt.lambda1, lambda2 = cv.tune.rcc$opt.lambda2)


## ----rCCA-scree, fig.cap='(ref:rCCA-scree)'----------
plot(rcc.nutri, type = "barplot")


## ----rCCA-scree2, fig.cap='(ref:rCCA-scree2)'--------
rcc.nutri2 <- rcc(X,Y, method = 'shrinkage')
plot(rcc.nutri2, type = "barplot")


## ----------------------------------------------------
rcc.nutri2$lambda


## ----------------------------------------------------
CV.rcc.nutri <- rcc(X,Y, ncomp = 3, 
                    lambda1 = cv.tune.rcc$opt.lambda1, lambda2 = cv.tune.rcc$opt.lambda2)
shrink.rcc.nutri <- rcc(X,Y, ncomp = 3, method = 'shrinkage')


## ----rCCA-sample-CV, echo = TRUE, results = 'hide', fig.show = 'hide', fig.path = 'Figures/Part3/'----
plotIndiv(CV.rcc.nutri, comp = 1:2, ind.names = nutrimouse$genotype,
          group = nutrimouse$diet, rep.space = "XY-variate",
          legend = TRUE, title = 'Nutrimouse, rCCA CV XY-space')


## ----rCCA-sample-shrink, echo = TRUE, results = 'hide', fig.show = 'hide', fig.path = 'Figures/Part3/'----
plotIndiv(shrink.rcc.nutri, comp = 1:2, ind.names = nutrimouse$genotype,
          group = nutrimouse$diet, rep.space = "XY-variate",
          legend = TRUE, title = 'Nutrimouse, rCCA XY-space')


## ----rCCA-sample, echo=FALSE, eval=TRUE, fig.cap='(ref:rCCA-sample)', fig.align="center", out.width = '50%', fig.height=4, fig.ncol = 2, fig.subcap=c('', '')----
knitr::include_graphics(c("Figures/Part3/rCCA-sample-CV-1.png", "Figures/Part3/rCCA-sample-shrink-1.png"))


## ----rCCA-arrow-CV, echo = TRUE, results = 'hide', fig.show = 'hide', fig.path = 'Figures/Part3/'----
plotArrow(CV.rcc.nutri, group = nutrimouse$diet,
          col.per.group = color.mixo(1:5),
          title = 'Nutrimouse, CV method')


## ----rCCA-arrow-shrink, echo = TRUE, results = 'hide', fig.show = 'hide', fig.path = 'Figures/Part3/'----
plotArrow(shrink.rcc.nutri, group = nutrimouse$diet,
          col.per.group = color.mixo(1:5), 
          title = 'Nutrimouse, shrinkage method')


## ----rCCA-arrow, fig.cap='(ref:rCCA-arrow)', echo=FALSE, eval=TRUE, fig.align="center", out.width = '50%', fig.height=4, fig.ncol = 2, fig.subcap=c('', '')----
knitr::include_graphics(c("Figures/Part3/rCCA-arrow-CV-1.png", "Figures/Part3/rCCA-arrow-shrink-1.png"))


## ---- eval = FALSE-----------------------------------
## col.diet <- color.mixo(as.numeric(nutrimouse$diet))
## plotIndiv(CV.rcc.nutri, comp = 1:3, ind.names = FALSE,
##           col = color.mixo(nutrimouse$diet), style = '3d')


## ----rCCA-circle-CV, echo = TRUE, results = 'hide', fig.show = 'hide', fig.path = 'Figures/Part3/'----
plotVar(CV.rcc.nutri, var.names = c(TRUE, TRUE),
        cex = c(4, 4), cutoff = 0.5, title = 'Nutrimouse, rCCA CV comp 1 - 2')


## ----rCCA-circle-shrink, echo = TRUE, results = 'hide', fig.show = 'hide', fig.path = 'Figures/Part3/'----
plotVar(shrink.rcc.nutri, var.names = c(TRUE, TRUE),
        cex = c(4, 4), cutoff = 0.5, title = 'Nutrimouse, rCCA shrinkage comp 1 - 2')


## ----rCCA-circle, fig.ncol=2, fig.show='hold',fig.cap='(ref:rCCA-circle)', fig.subcap=c('', ''), echo=FALSE, eval=TRUE, fig.align="center", out.width = '50%', fig.height=4----

knitr::include_graphics(c("Figures/Part3/rCCA-circle-CV-1.png", "Figures/Part3/rCCA-circle-shrink-1.png"))


## ----rCCA-cim, eval = FALSE--------------------------
## # X11() # To open a new window
## cim(CV.rcc.nutri, comp = 1:3, xlab = "genes", ylab = "lipids",
##     # To save the plot, otherwise comment out:
##     save = 'pdf', name.save = 'CIM_nutrimouse'
##     )


## ---- eval = FALSE-----------------------------------
## # X11() # To open a new window
## network(CV.rcc.nutri, comp = 1:3, interactive = FALSE,
##         lwd.edge = 2,
##         # To save the plot, otherwise comment out:
##         save = 'pdf', name.save = 'network_nutrimouse'
##         )


## ---- eval = FALSE-----------------------------------
## library(igraph)
## relev.net <- network(CV.rcc.nutri, comp = 1:3, interactive = FALSE,
##                      threshold = 0.5)
## write.graph(relev.net$gR, file = "network.gml", format = "gml")


## ----rCCA-imgcor2, fig.cap='(ref:rCCA-imgcor2)', out.width='40%', echo = FALSE----
var.coord <- plotVar(CV.rcc.nutri, var.names = c(TRUE, TRUE),
        cutoff = 0.6, title = 'Nutrimouse, rCCA CV comp 1 - 2',
        plot = FALSE)

list.lipid <- var.coord$names[var.coord$Block == 'X']
list.gene <- var.coord$names[var.coord$Block == 'Y']

# X11()
imgCor(X[, list.lipid], Y[, list.gene])


## ---- eval = FALSE-----------------------------------
## # PLS canonical mode
## nutri.pls <- pls(X, Y, ncomp = 3, mode = 'canonical')
## 
## # Comparison of the sample plots between PLS and rCCA with shrinkage
## plotIndiv(nutri.pls, group = nutrimouse$genotype, ind.names = nutrimouse$diet)
## plotIndiv(shrink.rcc.nutri, group = nutrimouse$genotype, ind.names = nutrimouse$diet)
## 
## # Correlation betwen canonical variates and PLS components (on diagonal)
## # corresponding to each data set
## cor(nutri.pls$variates$X, shrink.rcc.nutri$variates$X)
## cor(nutri.pls$variates$Y, shrink.rcc.nutri$variates$Y)
## 
## #Correlation circle plots highlight similar groups of strongly correlated variables
## plotVar(nutri.pls, cutoff = 0.5)
## plotVar(shrink.rcc.nutri, cutoff = 0.5)

